## maskcovid
maskcovid is a PyPI tool that predicts the number of people infected by day and up to one month from the date Japan began its liberal mask-wearing policy in the current Covid-19 epidemic.<br>

The goal of maskcovid is to determine if policies such as the liberalization of mask wearing are correct based on the increase or decrease in the number of infected people.<br>

Japan's policy of liberalizing the wearing of masks began on March 13, 2023.<br>

It is difficult to judge now (as of April 3, 2023) because only a little time has passed since the policy was initiated, but an increase in the number of infected people in the future could show that the policy was wrong.<br>

maskcovid scrapes the latest data from the following site over the Internet : https://covid19.mhlw.go.jp/public/opendata/newly_confirmed_cases_daily.csv<br>

## How to install maskcovid
```
$ pip install maskcovid
```

## How to run maskcovid

```
$ maskcovid
```
<img src="https://github.com/i-inose/maskcovid/blob/main/maskcovid.png?raw=true">


Written by Izuru Inose<br>
-At the Takefuji Lab-
